@@ -1,4 +1,4 @@
-from sqlglot import parse_one
+from sqlglot import parse_one, exp
 from sqlglot.optimizer.qualify import qualify
 from tests.dialects.test_dialect import Validator
 
@@ -226,6 +226,45 @@ class TestSingleStore(Validator):
                 "": 'SELECT JSON_FORMAT(\'["G","alpha","20",10]\')',
             },
         )
+        self.validate_all(
+            "SELECT JSON_AGG(name ORDER BY id ASC NULLS LAST, name DESC NULLS FIRST) FROM t",
+            read={
+                "singlestore": "SELECT JSON_AGG(name ORDER BY id ASC NULLS LAST, name DESC NULLS FIRST) FROM t",
+                "oracle": "SELECT JSON_ARRAYAGG(name ORDER BY id ASC, name DESC) FROM t",
+            },
+        )
+        self.validate_identity("SELECT JSON_AGG(name) FROM t")
+        self.validate_identity("SELECT JSON_AGG(t.*) FROM t")
+        self.validate_all(
+            "SELECT JSON_BUILD_ARRAY(id, name) FROM t",
+            read={
+                "singlestore": "SELECT JSON_BUILD_ARRAY(id, name) FROM t",
+                "oracle": "SELECT JSON_ARRAY(id, name) FROM t",
+            },
+        )
+        self.validate_identity("JSON_BUILD_ARRAY(id, name)").assert_is(exp.JSONArray)
+        self.validate_all(
+            "SELECT BSON_MATCH_ANY_EXISTS('{\"x\":true}', 'x')",
+            read={
+                "singlestore": "SELECT BSON_MATCH_ANY_EXISTS('{\"x\":true}', 'x')",
+                "": "SELECT JSONB_EXISTS('{\"x\":true}', 'x')",
+            },
+        )
+        self.validate_all(
+            "SELECT JSON_MATCH_ANY_EXISTS('{\"a\":1}', 'a')",
+            read={
+                "singlestore": "SELECT JSON_MATCH_ANY_EXISTS('{\"a\":1}', 'a')",
+                "oracle": "SELECT JSON_EXISTS('{\"a\":1}', '$.a')",
+            },
+        )
+        self.validate_all(
+            "SELECT JSON_BUILD_OBJECT('name', name) FROM t",
+            read={
+                "singlestore": "SELECT JSON_BUILD_OBJECT('name', name) FROM t",
+                "": "SELECT JSON_OBJECT('name', name) FROM t",
+            },
+        )
+        self.validate_identity("JSON_BUILD_OBJECT('name', name)").assert_is(exp.JSONObject)
 
     def test_date_parts_functions(self):
         self.validate_identity(
@@ -440,6 +479,34 @@ class TestSingleStore(Validator):
                 "singlestore": "SELECT LOWER('ABC') RLIKE LOWER('a.*')",
             },
         )
+        self.validate_all(
+            "SELECT CONCAT(SUBSTRING('abcdef', 1, 2 - 1), 'xyz', SUBSTRING('abcdef', 2 + 3))",
+            read={
+                "singlestore": "SELECT CONCAT(SUBSTRING('abcdef', 1, 2 - 1), 'xyz', SUBSTRING('abcdef', 2 + 3))",
+                "": "SELECT STUFF('abcdef', 2, 3, 'xyz')",
+            },
+        )
+        self.validate_all(
+            "SELECT SHA(email) FROM t",
+            read={
+                "singlestore": "SELECT SHA(email) FROM t",
+                "": "SELECT STANDARD_HASH(email) FROM t",
+            },
+        )
+        self.validate_all(
+            "SELECT SHA(email) FROM t",
+            read={
+                "singlestore": "SELECT SHA(email) FROM t",
+                "": "SELECT STANDARD_HASH(email, 'sha') FROM t",
+            },
+        )
+        self.validate_all(
+            "SELECT MD5(email) FROM t",
+            read={
+                "singlestore": "SELECT MD5(email) FROM t",
+                "": "SELECT STANDARD_HASH(email, 'MD5') FROM t",
+            },
+        )
 
     def test_reduce_functions(self):
         self.validate_all(
@@ -598,6 +665,31 @@ class TestSingleStore(Validator):
             },
             write={"": "SELECT CURRENT_TIME('UTC')"},
         )
+        self.validate_all(
+            "SELECT CURRENT_TIMESTAMP()",
+            read={
+                "": "SELECT CURRENT_TIMESTAMP()",
+                "singlestore": "SELECT CURRENT_TIMESTAMP",
+            },
+        )
+        self.validate_identity("SELECT CURRENT_TIMESTAMP(6)")
+        self.validate_all(
+            "SELECT UTC_TIMESTAMP()",
+            read={
+                "": "SELECT CURRENT_TIMESTAMP('UTC')",
+                "singlestore": "SELECT UTC_TIMESTAMP",
+            },
+            write={"": "SELECT CURRENT_TIMESTAMP('UTC')"},
+        )
+        self.validate_all(
+            "SELECT CURRENT_TIMESTAMP(6) :> DATETIME(6)",
+            read={
+                "bigquery": "SELECT CURRENT_DATETIME()",
+                "singlestore": "SELECT CURRENT_TIMESTAMP(6) :> DATETIME(6)",
+            },
+        )
+        self.validate_identity("SELECT UTC_TIMESTAMP(6)")
+        self.validate_identity("SELECT UTC_TIME(6)")
 
     def test_types(self):
         self.validate_all(
@@ -769,3 +861,90 @@ class TestSingleStore(Validator):
             "SELECT name :> LONGTEXT COLLATE 'utf8mb4_bin' FROM `users`",
             "SELECT name :> LONGTEXT :> LONGTEXT COLLATE 'utf8mb4_bin' FROM `users`",
         )
+
+    def test_match_against(self):
+        self.validate_identity(
+            "SELECT MATCH(name) AGAINST('search term') FROM products"
+        ).expressions[0].assert_is(exp.MatchAgainst)
+        self.validate_identity(
+            "SELECT MATCH(name, name) AGAINST('book') FROM products"
+        ).expressions[0].assert_is(exp.MatchAgainst)
+        self.validate_identity(
+            "SELECT MATCH(TABLE products2) AGAINST('search term') FROM products2"
+        ).expressions[0].assert_is(exp.MatchAgainst)
+
+    def test_show(self):
+        self.validate_identity("SHOW AGGREGATES FROM db1")
+        self.validate_identity("SHOW AGGREGATES LIKE 'multiply%'")
+        self.validate_identity("SHOW CDC EXTRACTOR POOL")
+        self.validate_identity("SHOW CREATE AGGREGATE avg_udaf")
+        self.validate_identity("SHOW CREATE PIPELINE mypipeline")
+        self.validate_identity("SHOW CREATE PROJECTION lineitem_sort_shipdate FOR TABLE lineitem")
+        self.validate_identity("SHOW DATABASE STATUS")
+        self.validate_identity("SHOW DISTRIBUTED_PLANCACHE STATUS")
+        self.validate_identity("SHOW FULLTEXT SERVICE STATUS")
+        self.validate_identity("SHOW FULLTEXT SERVICE METRICS LOCAL")
+        self.validate_identity("SHOW FULLTEXT SERVICE METRICS FOR NODE 1")
+        self.validate_identity("SHOW FUNCTIONS FROM db LIKE 'a'")
+        self.validate_identity("SHOW GROUPS")
+        self.validate_identity("SHOW GROUPS FOR ROLE 'role_name_0'")
+        self.validate_identity("SHOW GROUPS FOR USER 'root'")
+        self.validate_identity("SHOW INDEXES FROM mytbl", "SHOW INDEX FROM mytbl")
+        self.validate_identity("SHOW KEYS FROM mytbl", "SHOW INDEX FROM mytbl")
+        self.validate_identity("SHOW LINKS ON Orderdb")
+        self.validate_identity("SHOW LOAD ERRORS")
+        self.validate_identity("SHOW LOAD WARNINGS")
+        self.validate_identity("SHOW PARTITIONS ON memsql_demo")
+        self.validate_identity("SHOW PIPELINES")
+        self.validate_identity("SHOW PLAN JSON 25")
+        self.validate_identity("SHOW PLAN 25")
+        self.validate_identity("SHOW PLANCACHE")
+        self.validate_identity("SHOW PROCEDURES FROM dbExample")
+        self.validate_identity("SHOW PROCEDURES LIKE '%sp%'")
+        self.validate_identity("SHOW PROJECTIONS ON TABLE t")
+        self.validate_identity("SHOW PROJECTIONS")
+        self.validate_identity("SHOW REPLICATION STATUS")
+        self.validate_identity("SHOW REPRODUCTION")
+        self.validate_identity("SHOW REPRODUCTION INTO OUTFILE 'a'")
+        self.validate_identity("SHOW RESOURCE POOLS")
+        self.validate_identity("SHOW ROLES LIKE 'xyz'")
+        self.validate_identity("SHOW ROLES FOR GROUP 'group_0'")
+        self.validate_identity("SHOW ROLES FOR USER 'root'")
+        self.validate_identity("SHOW STATUS")
+        self.validate_identity("SHOW USERS")
+        self.validate_identity("SHOW USERS FOR GROUP 'group_name'")
+        self.validate_identity("SHOW USERS FOR ROLE 'role_name'")
+
+    def test_truncate(self):
+        self.validate_all(
+            "TRUNCATE t1; TRUNCATE t2",
+            read={
+                "": "TRUNCATE TABLE t1, t2",
+            },
+        )
+
+    def test_vector(self):
+        self.validate_all(
+            "CREATE TABLE t (a VECTOR(10, I32))",
+            read={
+                "snowflake": "CREATE TABLE t (a VECTOR(INT, 10))",
+                "singlestore": "CREATE TABLE t (a VECTOR(10, I32))",
+            },
+            write={
+                "snowflake": "CREATE TABLE t (a VECTOR(INT, 10))",
+            },
+        )
+        self.validate_all(
+            "CREATE TABLE t (a VECTOR(10))",
+            read={
+                "snowflake": "CREATE TABLE t (a VECTOR(10))",
+                "singlestore": "CREATE TABLE t (a VECTOR(10))",
+            },
+            write={
+                "snowflake": "CREATE TABLE t (a VECTOR(10))",
+            },
+        )
+
+    def test_alter(self):
+        self.validate_identity("ALTER TABLE t CHANGE middle_initial middle_name")
+        self.validate_identity("ALTER TABLE t MODIFY COLUMN name TEXT COLLATE 'binary'")
