@@ -1531,10 +1531,241 @@ STRING;
 -- Snowflake
 --------------------------------------
 
+# dialect: snowflake
+CHARINDEX('world', 'hello world');
+INT;
+
+# dialect: snowflake
+CHARINDEX('world', 'hello world', 1);
+INT;
+
+# dialect: snowflake
+CONCAT('Hello', 'World!');
+VARCHAR;
+
+# dialect: snowflake
+CONCAT(tbl.str_col, tbl.str_col, tbl.str_col);
+VARCHAR;
+
+# dialect: snowflake
+CONCAT_WS(':', 'one');
+VARCHAR;
+
+# dialect: snowflake
+CONCAT_WS(',', 'one', 'two', 'three');
+VARCHAR;
+
+# dialect: snowflake
+CONCAT_WS(tbl.bin_col, tbl.bin_col);
+BINARY;
+
+# dialect: snowflake
+CONTAINS('hello world', 'world');
+BOOLEAN;
+
+# dialect: snowflake
+CONTAINS(tbl.str_col, 'test');
+BOOLEAN;
+
+# dialect: snowflake
+CONTAINS(tbl.bin_col, tbl.bin_col);
+BOOLEAN;
+
+# dialect: snowflake
+CONTAINS(tbl.bin_col, NULL);
+BOOLEAN;
+
+# dialect: snowflake
+ENDSWITH('hello world', 'world');
+BOOLEAN;
+
+# dialect: snowflake
+ENDSWITH(tbl.str_col, 'test');
+BOOLEAN;
+
+# dialect: snowflake
+ENDSWITH(tbl.bin_col, tbl.bin_col);
+BOOLEAN;
+
+# dialect: snowflake
+ENDSWITH(tbl.bin_col, NULL);
+BOOLEAN;
+
 # dialect: snowflake
 LEAST(x::DECIMAL(18, 2));
 DECIMAL(18, 2);
 
+# dialect: snowflake
+LEFT('hello world', 5);
+VARCHAR;
+
+# dialect: snowflake
+LEFT(tbl.str_col, 3);
+STRING;
+
+# dialect: snowflake
+LEFT(tbl.bin_col, 3);
+BINARY;
+
+# dialect: snowflake
+LEFT(tbl.bin_col, NULL);
+BINARY;
+
+# dialect: snowflake
+LEN(tbl.str_col);
+INT;
+
+# dialect: snowflake
+LEN(tbl.bin_col);
+INT;
+
+# dialect: snowflake
+LENGTH(tbl.str_col);
+INT;
+
+# dialect: snowflake
+LENGTH(tbl.bin_col);
+INT;
+
+# dialect: snowflake
+LOWER(tbl.str_col);
+VARCHAR;
+
+# dialect: snowflake
+REVERSE('Hello, world!');
+VARCHAR;
+
+# dialect: snowflake
+REVERSE(tbl.str_col);
+VARCHAR;
+
+# dialect: snowflake
+REVERSE(tbl.bin_col);
+BINARY;
+
+# dialect: snowflake
+REVERSE(NULL);
+VARCHAR;
+
+# dialect: snowflake
+RIGHT('hello world', 5);
+VARCHAR;
+
+# dialect: snowflake
+RIGHT(tbl.str_col, 3);
+STRING;
+
+# dialect: snowflake
+RIGHT(tbl.bin_col, 3);
+BINARY;
+
+# dialect: snowflake
+RIGHT(tbl.str_col, NULL);
+STRING;
+
+# dialect: snowflake
+STARTSWITH('hello world', 'hello');
+BOOLEAN;
+
+# dialect: snowflake
+STARTSWITH(tbl.str_col, 'test');
+BOOLEAN;
+
+# dialect: snowflake
+STARTSWITH(tbl.bin_col, tbl.bin_col);
+BOOLEAN;
+
+# dialect: snowflake
+STARTSWITH(tbl.bin_col, NULL);
+BOOLEAN;
+
+# dialect: snowflake
+SUBSTR('hello world', 1, 5);
+VARCHAR;
+
+# dialect: snowflake
+SUBSTR(tbl.str_col, 1, 3);
+STRING;
+
+# dialect: snowflake
+SUBSTR(tbl.bin_col, 1, 3);
+BINARY;
+
+# dialect: snowflake
+SUBSTR(tbl.str_col, NULL);
+STRING;
+
+# dialect: snowflake
+TRIM('hello world');
+VARCHAR;
+
+# dialect: snowflake
+TRIM('hello world', 'hello');
+VARCHAR;
+
+# dialect: snowflake
+TRIM(tbl.str_col);
+VARCHAR;
+
+# dialect: snowflake
+TRIM(tbl.str_col, tbl.str_col);
+VARCHAR;
+
+# dialect: snowflake
+TRIM(NULL);
+VARCHAR;
+
+# dialect: snowflake
+LTRIM('  hello world  ');
+VARCHAR;
+
+# dialect: snowflake
+LTRIM(tbl.str_col);
+VARCHAR;
+
+# dialect: snowflake
+LTRIM(NULL);
+VARCHAR;
+
+# dialect: snowflake
+RTRIM('  hello world  ');
+VARCHAR;
+
+# dialect: snowflake
+RTRIM(tbl.str_col);
+VARCHAR;
+
+# dialect: snowflake
+RTRIM(NULL);
+VARCHAR;
+
+# dialect: snowflake
+UPPER('Hello, world!');
+VARCHAR;
+
+# dialect: snowflake
+UPPER(tbl.str_col);
+VARCHAR;
+
+# dialect: snowflake
+REPLACE(tbl.str_col, 'old', 'new');
+VARCHAR;
+
+# dialect: snowflake
+REPLACE('hello', 'old', NULL);
+VARCHAR;
+
+# dialect: snowflake
+SPACE(5);
+VARCHAR;
+
+# dialect: snowflake
+SPACE(tbl.int_col);
+VARCHAR;
+
+# dialect: snowflake
+SPACE(NULL);
+VARCHAR;
 --------------------------------------
 -- T-SQL
 --------------------------------------
